Repo

Enum Repo 

pub enum Repo {
    Local {},
    Meta {},
    Repo {
        repo: String,
        rev: String,
        hooks: Vec<Hook>,
    },
}
A repository, i.e. where to get one or more hooks from.

This concept is slightly overloaded in pre-commit, as there are two special sentinel “repository” types, local, and meta, which have a different shape than a normal Git repository.

Variants



Local

A special ‘local’ repository, for hooks defined within the current Git repository.

See: https://pre-commit.com/#repository-local-hooks



Meta

A special ‘meta’ repository, for hooks defined by pre-commit itself.

See: https://pre-commit.com/#meta-hooks



Repo

Fields

repo: String
hooks: Vec<Hook>