pub struct Hook {Show 15 fields
pub id: String,
pub alias: Option<String>,
pub name: Option<String>,
pub language_version: Option<String>,
pub files: Option<String>,
pub exclude: Option<String>,
pub types: Option<Vec<String>>,
pub types_or: Option<Vec<String>>,
pub exclude_types: Option<Vec<String>>,
pub args: Vec<String>,
pub stages: Option<Vec<String>>,
pub additional_dependencies: Vec<String>,
pub always_run: bool,
pub verbose: bool,
pub log_file: Option<String>,
}Expand description
A single hook.
Fields
id: StringThe ID of the hook to use.
alias: Option<String>An optional additional ID to use when referring to the hook.
name: Option<String>Overrides the name of the hook, as shown during execution.
language_version: Option<String>Overrides the language version for the hook.
files: Option<String>Overrides the files pattern for the hook.
exclude: Option<String>Overrides the exclude pattern for the hook.
types: Option<Vec<String>>Overrides the default file types to run on for the hook (AND).
types_or: Option<Vec<String>>Overrides the default file types to run on for the hook (OR).
exclude_types: Option<Vec<String>>Overrides the types to exclude for the hook.
args: Vec<String>Optional list of additional args to supply to the hook.
stages: Option<Vec<String>>Overrides the set of stages to run the hook for.
additional_dependencies: Vec<String>Additional dependencies to install into the hook’s environment.
always_run: boolIf true, run the hook even when there are no matching files.
verbose: boolIf true, force the hook’s output to be printed even if it passes.
log_file: Option<String>If present, additionally append the hook’s log output to this file.