pub enum Repo {
Local {},
Meta {},
Repo {
repo: String,
rev: String,
hooks: Vec<Hook>,
},
}Expand description
A repository, i.e. where to get one or more hooks from.
This concept is slightly overloaded in pre-commit, as there are
two special sentinel “repository” types, local, and meta, which
have a different shape than a normal Git repository.
Variants
Local
A special ‘local’ repository, for hooks defined within the current Git repository.
Meta
A special ‘meta’ repository, for hooks defined by pre-commit itself.
Repo